package com.ruoyi.powerdistribution.mapper;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmReportAppointmentWeek;

/**
 * 履职周统计Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-29
 */
public interface PdmReportAppointmentWeekMapper
{
    /**
     * 查询履职周统计
     *
     * @param id 履职周统计主键
     * @return 履职周统计
     */
    public PdmReportAppointmentWeek selectPdmReportAppointmentWeekById(Long id);

    /**
     * 查询履职周统计列表
     *
     * @param pdmReportAppointmentWeek 履职周统计
     * @return 履职周统计集合
     */
    public List<PdmReportAppointmentWeek> selectPdmReportAppointmentWeekList(PdmReportAppointmentWeek pdmReportAppointmentWeek);

    /**
     * 新增履职周统计
     *
     * @param pdmReportAppointmentWeek 履职周统计
     * @return 结果
     */
    public int insertPdmReportAppointmentWeek(PdmReportAppointmentWeek pdmReportAppointmentWeek);

    /**
     * 修改履职周统计
     *
     * @param pdmReportAppointmentWeek 履职周统计
     * @return 结果
     */
    public int updatePdmReportAppointmentWeek(PdmReportAppointmentWeek pdmReportAppointmentWeek);

    /**
     * 删除履职周统计
     *
     * @param id 履职周统计主键
     * @return 结果
     */
    public int deletePdmReportAppointmentWeekById(Long id);

    /**
     * 批量删除履职周统计
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePdmReportAppointmentWeekByIds(Long[] ids);
}
